@@ -1,7 +1,7 @@
 package App::instopt;
 
-our $DATE = '2019-10-07'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2019-10-09'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -49,6 +49,8 @@ our %argopt_download = (
     download => {
         summary => 'Whether to download latest version from URL'.
             'or just find from download dir',
+        'summary.alt.bool.not' => 'Do not download latest version from URL, '.
+            'just find from download dir',
         schema => 'bool*',
         default => 1,
         cmdline_aliases => {
@@ -58,8 +60,10 @@ our %argopt_download = (
 );
 
 our %argopt_make_latest_dir_as_symlink = (
-    symlink => {
+    make_latest_dir_as_symlink => {
         summary => 'Whether to use symlink to create the latest version directory',
+        'summary.alt.bool.not' => 'Do not use symlink to create latest version directory, '.
+            'but hard-copy instead',
         schema => ['bool*'],
         default => 1,
         description => <<'_',
@@ -892,7 +896,7 @@ App::instopt - Download and install software
 
 =head1 VERSION
 
-This document describes version 0.011 of App::instopt (from Perl distribution App-instopt), released on 2019-10-07.
+This document describes version 0.012 of App::instopt (from Perl distribution App-instopt), released on 2019-10-09.
 
 =head1 SYNOPSIS
 
@@ -1280,11 +1284,7 @@ Whether to download latest version from URLor just find from download dir.
 
 =item * B<install_dir> => I<dirname>
 
-=item * B<program_dir> => I<dirname>
-
-=item * B<softwares_or_patterns>* => I<array[str]>
-
-=item * B<symlink> => I<bool> (default: 1)
+=item * B<make_latest_dir_as_symlink> => I<bool> (default: 1)
 
 Whether to use symlink to create the latest version directory.
 
@@ -1309,6 +1309,10 @@ Currently hardlinking is performed using the C<cp> command (with the option
 C<-la>), so you need to have this on your system (normally present on all Unix
 systems).
 
+=item * B<program_dir> => I<dirname>
+
+=item * B<softwares_or_patterns>* => I<array[str]>
+
 =back
 
 Returns an enveloped result (an array).
@@ -1346,9 +1350,7 @@ Whether to download latest version from URLor just find from download dir.
 
 =item * B<install_dir> => I<dirname>
 
-=item * B<program_dir> => I<dirname>
-
-=item * B<symlink> => I<bool> (default: 1)
+=item * B<make_latest_dir_as_symlink> => I<bool> (default: 1)
 
 Whether to use symlink to create the latest version directory.
 
@@ -1373,6 +1375,8 @@ Currently hardlinking is performed using the C<cp> command (with the option
 C<-la>), so you need to have this on your system (normally present on all Unix
 systems).
 
+=item * B<program_dir> => I<dirname>
+
 =back
 
 Returns an enveloped result (an array).
